@@ -1,4 +1,4 @@
-from inspect import ismodule, isfunction, signature, Parameter
+from inspect import ismodule, isfunction, signature, Parameter, stack, getmodule
 from importlib import import_module
 from sys import modules
 from os.path import exists, join
@@ -125,8 +125,8 @@ def __get_function_obj(func, module=None, package_path=None):
             if isinstance(package_path, str):
                 module = __get_module_obj(module=module, package_path=package_path)
 
-            elif hasattr(__get_cur_module(), func):
-                module = __get_cur_module()
+            elif hasattr(getmodule(stack()[2][0]), func):
+                module = getmodule(stack()[2][0])
 
             else:
                 raise ValueError('If the function is not in the current module, package_path must specify the directory!')
@@ -154,9 +154,6 @@ def gexec(func, params, module=None, package_path=None):
     :param package_path: String
     :return: None | Object
 
-    >>> gexec(func=__subset_dictionary, params={'dict_': {'a': 1, 'b': 2}, 'subset_keys': {'a'}})
-    {'a': 1}
-
     >>> gexec(func='__subset_dictionary', params={'dict_': {'a': 1, 'b': 2}, 'subset_keys': {'a'}})
     {'a': 1}
 
